translate.convert.po2json

Package translate :: Package convert :: Module po2json |
[hide private]
[frames] | no frames]

# Module po2json

source code

Convert Gettext PO localization files to JSON files

Classes | [hide private]
| rejson

Functions | [hide private]
convertjson(inputfile, outputfile, templatefile, includefuzzy=False) | source code
main(argv=None) | source code

Variables | [hide private]
| __package__ = ``'``translate.convert``'``

Imports: factory